<?php
/**
 * Plugin name: ADB tools
 * Description: Get informations from ADB API project
 * Author: Virgil Goudal & Alexis Pannetier
 * version: 1.0.0
 * text-domain: adb-tools
 */

// If this file is access directly, abort!!!
defined( 'ABSPATH' ) or die( 'Unauthorized Access' );

function plugin_adb_register_scripts() {
  if(get_option('enable_lottie')) {
    wp_enqueue_script('lottie', 'https://unpkg.com/@lottiefiles/lottie-player@latest/dist/lottie-player.js', array(), "1.0.0", true );
  }
}

if (!is_admin()) {
  add_action("wp_enqueue_scripts", "plugin_adb_register_scripts");
}

function adb_init_session() {
  if (!session_id() ) {
      session_start();
      $_SESSION['adb_id'] = 90;
      session_write_close();
  }
}
// Start session on init hook.
add_action( 'init', 'adb_init_session' );

#region -----SHORTCODES-----
function get_server_button() {
	ob_start();
  session_start();
  include(plugin_dir_path( __FILE__ ) . 'templates/client/server-button.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('server-button', 'get_server_button');

function get_annonces_highlight($atts = [], $content = null, $tag = '') {
	$wporg_atts = shortcode_atts(
    // DEFAULT VALUES
    array(
      'col' => 4, // How much annonce by row
      'nombre' => 4, // How much annonce show
      'description' => 0, // Hide description by default
      'favoris' => 0, // Check favoris by default
      'nouveaute' => 0, // Check nouveaute by default.
      'exclusivite' => 0, // Check exclusivite by default
      'sous_compromis' => 0, // Check sous_compromis by default.
      'transaction_vente' => 0, // Check transaction vente by default
      'transaction_location' => 0, // Check transaction location by default
      'transaction_programme_neuf' => 0, // Check transaction programme_neuf by default
      'transaction_location_saisonniere' => 0, // Check transaction loc_saison by default
    ), $atts, $tag
  );
  ob_start();
  session_start();
  $_SESSION['atts_col'] = esc_html__( $wporg_atts['col'], 'wporg' );
  $_SESSION['atts_nombre'] = esc_html__( $wporg_atts['nombre'], 'wporg' );
  $_SESSION['atts_description'] = esc_html__( $wporg_atts['description'], 'wporg' );
  $_SESSION['atts_favoris'] = esc_html__( $wporg_atts['favoris'], 'wporg' );
  $_SESSION['atts_nouveaute'] = esc_html__( $wporg_atts['nouveaute'], 'wporg' );
  $_SESSION['atts_exclusivite'] = esc_html__( $wporg_atts['exclusivite'], 'wporg' );
  $_SESSION['atts_sous_compromis'] = esc_html__( $wporg_atts['sous_compromis'], 'wporg' );
  $_SESSION['atts_transaction_vente'] = esc_html__( $wporg_atts['transaction_vente'], 'wporg' );
  $_SESSION['atts_transaction_location'] = esc_html__( $wporg_atts['transaction_location'], 'wporg' );
  $_SESSION['atts_transaction_programme_neuf'] = esc_html__( $wporg_atts['transaction_programme_neuf'], 'wporg' );
  $_SESSION['atts_transaction_location_saisonniere'] = esc_html__( $wporg_atts['transaction_location_saisonniere'], 'wporg' );
  include(plugin_dir_path( __FILE__ ) . 'templates/annonces/highlight.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('annonces-highlight', 'get_annonces_highlight');

function get_annonces_filter($atts = [], $content = null, $tag = '') {
  $wporg_atts = shortcode_atts(
    // DEFAULT VALUES
    array(
      'transaction_vente' => 0, // Check transaction vente by default
      'transaction_location' => 0, // Check transaction location by default
      'transaction_programme_neuf' => 0, // Check transaction programme_neuf by default
      'transaction_location_saisonniere' => 0, // Check transaction loc_saison by default
      'transaction' => 1, // enable transaction filter
      'type' => 1, // Enable Type filter
      'room' => 1, // Enable Rooom filter
      'surface' => 1, // Enable surface filter
      'price' => 1, // Enable price filter
    ), $atts, $tag
  );
  ob_start();
  session_start();
  $_SESSION['atts_transaction'] = esc_html__( $wporg_atts['transaction'], 'wporg' );
  $_SESSION['atts_transaction_vente'] = esc_html__( $wporg_atts['transaction_vente'], 'wporg' );
  $_SESSION['atts_transaction_location'] = esc_html__( $wporg_atts['transaction_location'], 'wporg' );
  $_SESSION['atts_transaction_programme_neuf'] = esc_html__( $wporg_atts['transaction_programme_neuf'], 'wporg' );
  $_SESSION['atts_transaction_location_saisonniere'] = esc_html__( $wporg_atts['transaction_location_saisonniere'], 'wporg' );
  $_SESSION['atts_type'] = esc_html__( $wporg_atts['type'], 'wporg' );
  $_SESSION['atts_room'] = esc_html__( $wporg_atts['room'], 'wporg' );
  $_SESSION['atts_surface'] = esc_html__( $wporg_atts['surface'], 'wporg' );
  $_SESSION['atts_price'] = esc_html__( $wporg_atts['price'], 'wporg' );

  include(plugin_dir_path( __FILE__ ) . 'templates/annonces/filter.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('annonces-filter', 'get_annonces_filter');

function get_annonces_pagination() {
	ob_start();
  session_start();
  include(plugin_dir_path( __FILE__ ) . 'templates/annonces/pagination.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('annonces-pagination', 'get_annonces_pagination');

function get_annonces($atts = [], $content = null, $tag = '') {
  $wporg_atts = shortcode_atts(
    // DEFAULT VALUES
    array(
      'col' => 4, // How much annonce by row
    ), $atts, $tag
  );
  ob_start();
  session_start();
  $_SESSION['atts_col'] = esc_html__( $wporg_atts['col'], 'wporg' );

	ob_start();
  session_start();
  include(plugin_dir_path( __FILE__ ) . 'templates/annonces.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('annonces', 'get_annonces');

function get_annonce() {
	ob_start();
  session_start();
  include(plugin_dir_path( __FILE__ ) . 'templates/annonce.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('annonce', 'get_annonce');

function get_annonces_saison($atts = [], $content = null, $tag = '') {
  $wporg_atts = shortcode_atts(
    // DEFAULT VALUES
    array(
      'col' => 4, // How much annonce by row
    ), $atts, $tag
  );
  ob_start();
  session_start();
  $_SESSION['atts_col'] = esc_html__( $wporg_atts['col'], 'wporg' );

	ob_start();
  session_start();
  include(plugin_dir_path( __FILE__ ) . 'templates/annonces-saison.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('annonces-saison', 'get_annonces_saison');

function get_annonce_saison() {
	ob_start();
  session_start();
  include(plugin_dir_path( __FILE__ ) . 'templates/annonce-saison.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('annonce-saison', 'get_annonce_saison');

function map($atts = [], $content = null, $tag = '') {
  $wporg_atts = shortcode_atts(
    // DEFAULT VALUES
    array(
      'src' => "",
      'width' => 600,
      'height' => 400,
      'style' => "",
      'allowfullscreen' => "",
      'loading' => "",
      'referrerpolicy' => "",
    ), $atts, $tag
  );

  ob_start();
  session_start();
  $_SESSION['atts_src'] = esc_html__( $wporg_atts['src'], 'wporg' );
  $_SESSION['atts_width'] = esc_html__( $wporg_atts['width'], 'wporg' );
  $_SESSION['atts_height'] = esc_html__( $wporg_atts['height'], 'wporg' );
  $_SESSION['atts_style'] = esc_html__( $wporg_atts['style'], 'wporg' );
  $_SESSION['atts_allowfullscreen'] = esc_html__( $wporg_atts['allowfullscreen'], 'wporg' );
  $_SESSION['atts_loading'] = esc_html__( $wporg_atts['loading'], 'wporg' );
  $_SESSION['atts_referrerpolicy'] = esc_html__( $wporg_atts['referrerpolicy'], 'wporg' );

  include(plugin_dir_path( __FILE__ ) . 'templates/map.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('map', 'map');

function get_auth() {
	ob_start();
  session_start();
  $user_menu = plugin_dir_path( __FILE__ ) . 'templates/auth/user-menu.php';
  $login_form = plugin_dir_path( __FILE__ ) . 'templates/auth/login-form.php';
  include(plugin_dir_path( __FILE__ ) . 'templates/auth/auth.php');
  session_write_close();
  return ob_get_clean();
}

add_shortcode('auth', 'get_auth');
#endregion

#region -----Email-----
  // Disable email notification
  add_filter( 'auto_plugin_update_send_email', '__return_false' );
  add_filter( 'auto_theme_update_send_email', '__return_false' );
  add_filter( 'auto_core_update_send_email', 'wpb_stop_auto_update_emails', 10, 4 );
    
  function wpb_stop_update_emails( $send, $type, $core_update, $result ) {
  if ( ! empty( $type ) && $type == 'success' ) {
  return false;
  }
  return true;
  }
#endregion

#region -----MENU-----
add_action('admin_menu', 'addMenu');

function addMenu() {
  add_menu_page( 
    __( 'ADB Tools', 'textdomain' ),
    'ADB tools',
    'manage_options',
    'adb-tools',
    'adbMenu',
    'dashicons-admin-multisite',
    100
);

add_submenu_page( 'adb-tools', 'Réglage', 'Réglage',
    'manage_options', 'adb-tools'); 

add_submenu_page( 'adb-tools', 'Documentation', 'Documentation',
    'manage_options', 'documentation', 'documentation'); 

add_submenu_page( 'adb-tools', 'Personnaliser', 'Apparence/Personnaliser',
    'manage_options', 'customize.php'); 
}

function adbMenu() {
  global $title;
  include(plugin_dir_path( __FILE__ ) . 'templates/menu/adb-tools.php');
}

function documentation() {
  global $title;
  include(plugin_dir_path( __FILE__ ) . 'templates/menu/documentation.php');
}

#endregion

#region ---TOOLS---
function enable_extended_upload($mimes = array()) {
  $mimes['exe'] = 'application/exe';
	$mimes['svg'] = 'image/svg+xml';
  $mimes['json'] = 'text/plain'; 
	return $mimes;
}

if(get_option('custom_media')) {
  add_filter('upload_mimes', 'enable_extended_upload');
}
#endregion

#region -----UTILS-----
function sortByOrder($a, $b)
{
    return strcmp($a->photo_ordre, $b->photo_ordre);
}

function register_adb_settings()
{
  $api_args = array(
    'type' => 'integer', 
    'sanitize_callback' => 'sanitize_text_field',
    'default' => null,
  );
  $society_id_args = array(
    'type' => 'integer', 
    'sanitize_callback' => 'sanitize_text_field',
    'default' => null,
  );
  $per_page_args = array(
    'type' => 'integer', 
    'sanitize_callback' => 'sanitize_text_field',
    'default' => 50,
  );
  $client_page_args = array(
    'type' => 'integer',
    'sanitize_callback' => 'sanitize_text_field',
    'default' => null,
  );
  $annonces_page_args = array(
    'type' => 'integer',
    'sanitize_callback' => 'sanitize_text_field',
    'default' => null,
  );
  $annonce_page_args = array(
    'type' => 'integer',
    'sanitize_callback' => 'sanitize_text_field',
    'default' => null,
  );
  $annonces_saison_page_args = array(
    'type' => 'integer',
    'sanitize_callback' => 'sanitize_text_field',
    'default' => null,
  );
  $annonce_saison_page_args = array(
    'type' => 'integer',
    'sanitize_callback' => 'sanitize_text_field',
    'default' => null,
  );
  $custom_media_args = array(
    'type' => 'boolean', 
    'sanitize_callback' => 'sanitize_text_field',
    'default' => false,
  );
  $enable_lottie = array(
    'type' => 'boolean', 
    'sanitize_callback' => 'sanitize_text_field',
    'default' => false,
  );
  register_setting('adbsettings','api', $api_args);
  register_setting('adbsettings','societe_id', $society_id_args);
  register_setting('adbsettings','per_page', $per_page_args);
  register_setting('adbsettings','client_page', $client_page_args);
  register_setting('adbsettings','annonces_page', $annonces_page_args);
  register_setting('adbsettings','annonce_page', $annonce_page_args);
  register_setting('adbsettings','annonces_saison_page', $annonces_saison_page_args);
  register_setting('adbsettings','annonce_saison_page', $annonce_saison_page_args);
  register_setting('adbsettings','custom_media', $custom_media_args);
  register_setting('adbsettings','enable_lottie', $enable_lottie);
}

add_action('admin_init', 'register_adb_settings');
#endregion