<?php
    // DEFAULT
    $default_sorter = "date_desc";

    // FILTERS
    $_SESSION['transaction_vente'] = $_SESSION['atts_transaction_vente'] > 0;
    $_SESSION['transaction_location'] = $_SESSION['atts_transaction_location'] > 0;
    $_SESSION['transaction_nouveau_programme'] = $_SESSION['atts_transaction_programme_neuf'] > 0;
    $_SESSION['transaction_location_saisonniere'] = $_SESSION['atts_transaction_location_saisonniere'] > 0;
    $_SESSION['nombre'] = $_SESSION['atts_nombre'];
    $_SESSION['favoris'] = $_SESSION['atts_favoris'] > 0;
    $_SESSION['nouveaute'] = $_SESSION['atts_nouveaute'] > 0;
    $_SESSION['exclusivite'] = $_SESSION['atts_exclusivite'] > 0;
    $_SESSION['sous_compromis'] = $_SESSION['atts_sous_compromis'] > 0;

    // SORTER
    $_SESSION['sort'] = $default_sorter; // if null set default

    // Prepare api request
    $current_page = isset($_GET['current_page']) ? $_GET['current_page'] : 1;
    $url = get_option("api") . '/api/wordpress/societes/' . get_option("societe_id") . '/lots';
    $url = add_query_arg( 'per_page', $_SESSION['nombre'], $url);
    $url = add_query_arg( 'favoris', $_SESSION['favoris'], $url);
    $url = add_query_arg( 'nouveaute', $_SESSION['nouveaute'], $url);
    $url = add_query_arg( 'exclusivite', $_SESSION['exclusivite'], $url);
    $url = add_query_arg( 'sous_compromis', $_SESSION['sous_compromis'], $url);
    $url = add_query_arg( 'transaction_vente', $_SESSION['transaction_vente'], $url);
    $url = add_query_arg( 'transaction_location', $_SESSION['transaction_location'], $url);
    $url = add_query_arg( 'transaction_nouveau_programme', $_SESSION['transaction_nouveau_programme'], $url);
    $url = add_query_arg( 'transaction_location_saisonniere', $_SESSION['transaction_location_saisonniere'], $url);
    $url = add_query_arg( 'sort', $_SESSION['sort'], $url);
    $request = wp_remote_get($url,
        ['headers'     => [
                "Accept"=> "application/json",
                "Content-Type"=> "application/json",
            ]
        ]
    );
    if( is_wp_error($request) ) {
        return false; // stop if error
    } else {
        $body = json_decode(wp_remote_retrieve_body( $request ));
        $lots = [];
        if (isset($body)) {
            if (isset($body->message)) {
                echo "<script>console.error('Problème lors de la récupération des annonces depuis l\'API' );</script>";
            } else {
                $lots = $body->lot;
            }
        }
    }
?>

<div id="annonces">
    <?php if (isset($lots)) : ?>
        <div id="item-layout" class="row justify-content-center g-3">
        <?php
        $description_max = 80;
        foreach( $lots as $item ) :
            $id = $item->lot_id;
            $description = $item->lot_description;
            $description_short = mb_substr($item->lot_description, 0, $description_max);
            $favoris = $item->lot_favoris;
            $nouveaute = $item->lot_nouveaute;
            $exclusivite = $item->lot_exclusivite;
            $sous_compromis = $item->lot_sous_compromis;
            $miniature = $item->lot_miniature;
            $montant = number_format($item->lot_montant, 0, ',', '.');
            $nombre_piece = $item->lot_nombre_piece;
            $surface = $item->lot_surface;
            $transaction = $item->lot_transaction;
            $titre = $item->lot_titre;
            $type = $item->lot_type;
            $src_image = filter_var($miniature, FILTER_VALIDATE_URL) ? $miniature : get_option("api") . $miniature;
            // Responsive layout
            $col_lg= round(12 / $_SESSION['atts_col']);
            $col_md= (($_SESSION['atts_col']) > 3) ? 4 : $col_lg;
            $col_sm= (($_SESSION['atts_col']) > 1) ? 6 : 12;
        ?>
        <div class='col-12 col-sm-<?php echo $col_sm ?> col-md-<?php echo $col_md ?> col-lg-<?php echo $col_lg ?>'>
            <div class="card elevation h-100">
                <a href="<?php echo add_query_arg('id', $id, get_permalink(get_option("annonce_page")) . '#annonce'); ?>" class='text-reset text-decoration-none'>
                    <div class='row g-0'>
                        <div class="col-img col-12">
                            <?php if (isset($miniature)) : ?>
                                <img alt="Photo du bien immobilier" style="max-height:200px" src="<?php echo $src_image ?>">
                            <?php endif ?>
                            <?php if($favoris) : ?>
                                <div class="corner-ribbon bg-favoris top-left">Favoris</div>
                            <?php endif ?>
                            <?php if($exclusivite) : ?>
                                <div class="corner-ribbon bg-exclusivite bottom-left">Exclusivité</div>
                            <?php endif ?>
                            <?php if($nouveaute) : ?>
                                <div class="corner-ribbon bg-new top-right">Nouveau</div>
                            <?php endif ?>
                            <?php if($sous_compromis) : ?>
                                <div class="corner-ribbon bg-compromis bottom-right">Sous compromis</div>
                            <?php endif ?>
                        </div>
                        <div class="col-body" style="z-index: 1">
                            <div class="card-body h-100 d-flex justify-content-between flex-column">
                                <div class="text-center">
                                    <h5 class="card-title m-0"><strong><?php echo $titre ?></strong></h5>
                                    <?php if (isset($transaction)) : ?>
                                        <span>
                                            <?php echo $transaction ?>
                                        </span>
                                    <?php endif ?>

                                    <?php if (isset($type)) : ?>
                                        <span>
                                            <?php echo $type ?>
                                        </span>
                                    <?php endif ?>

                                    <?php if (isset($nombre_piece)) : ?>
                                        <span>
                                            <?php echo $nombre_piece ?> pièces
                                        </span>
                                    <?php endif ?>
                                   
                                    <?php if (isset($surface)) : ?>
                                        <span>
                                            <?php echo $surface ?> m²
                                        </span>
                                    <?php endif ?>

                                    <?php if(isset($montant)) : ?>
                                        <span class="d-block text-success"><?php echo $montant ?> €</span>
                                    <?php endif ?>
                                </div>

                                    <?php if($_SESSION['atts_description'] && isset($description_short)) : ?>
                                        <div class="description">
                                            <p class="mb-0">
                                                <?php echo $description_short ?>
                                                <?php if(strlen($description) > $description_max) echo "..." ?>
                                            </p>
                                        </div>
                                    <?php endif ?>

                                </div>
                            </div>
                        </div>
                    </a>
                </div>
            </div>
        <?php endforeach;?>

        <div class="d-flex justify-content-center my-4">
            <a href="<?php echo get_permalink(get_option("annonces_page") . '#annonces'); ?>" class='wp-block-button__link has-custom-font-size has-small-font-size'>
                Voir les annonces                                
            </a>
        </div>
    </div>
    <?php else : ?>
        <?php include(plugin_dir_path( __FILE__ ) . 'empty.php') ?>
    <?php endif; ?>

</div>